@@ -18,8 +18,8 @@
 
 use self::errors::*;
 use crate::lalr::TokenType;
-use dmntk_common::Result;
 use dmntk_feel::context::FeelContext;
+use dmntk_feel::dmntk_common::Result;
 use dmntk_feel::values::VALUE_NULL;
 use dmntk_feel::{Name, Scope};
 
@@ -1004,7 +1004,7 @@ fn flatten_name_parts(parts: &[String]) -> String {
 
 /// Definitions of errors raised by the lexer.
 pub mod errors {
-  use dmntk_common::DmntkError;
+  use dmntk_feel::dmntk_common::DmntkError;
 
   /// Lexer errors.
   #[derive(Debug, PartialEq)]
