@@ -19,8 +19,8 @@
 use self::errors::*;
 use crate::lalr::{TokenType, *};
 use crate::lexer::{Lexer, TokenValue};
-use dmntk_common::Result;
 use dmntk_feel::context::FeelContext;
+use dmntk_feel::dmntk_common::Result;
 use dmntk_feel::values::VALUE_NULL;
 use dmntk_feel::{AstNode, FeelType, Name, Scope};
 
@@ -1123,7 +1123,7 @@ impl<'parser> Parser<'parser> {
 
 /// Definitions of errors raised by [parser](crate::parser) module.
 mod errors {
-  use dmntk_common::DmntkError;
+  use dmntk_feel::dmntk_common::DmntkError;
 
   /// Definition of errors raised by [Parser](super::Parser).
   enum ParserError {
