@@ -14,11 +14,9 @@
  * SOFTWARE.
  */
 
+use super::{accept, empty_scope};
+use crate::lalr::TokenType::StartTextualExpression;
 use dmntk_feel::values::VALUE_NULL;
-use {
-  super::{accept, empty_scope},
-  crate::lalr::TokenType::StartTextualExpression,
-};
 
 #[test]
 fn test_instance_of_1() {
