@@ -14,11 +14,10 @@
  * SOFTWARE.
  */
 
-use {
-  crate::{lalr::TokenType, parser::Parser},
-  difference::Changeset,
-  dmntk_feel::{values::VALUE_NULL, Scope},
-};
+use crate::lalr::TokenType;
+use crate::parser::Parser;
+use difference::Changeset;
+use dmntk_feel::{Name, Scope};
 
 mod addition;
 mod between;
@@ -53,7 +52,14 @@ fn accept(scope: &Scope, start_token_type: TokenType, input: &str, expected: &st
 }
 
 #[test]
-fn test_dev() {
+fn test_parse_name() {
+  let name_a: Name = Name::new(&["Full", "House"]);
   let scope = &mut empty_scope();
-  scope.set_entry(&"Person".into(), VALUE_NULL);
+  assert_eq!(name_a, crate::parse_name(scope, "Full House", false).unwrap());
+}
+
+#[test]
+fn test_parse_longest_name() {
+  let name_a: Name = Name::new(&["Full", "House", "With", "A", "Cat"]);
+  assert_eq!(name_a, crate::parse_longest_name(" Full House  With  \t A \n\n Cat    ").unwrap());
 }
